# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/timeline/timeline.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf.activities import activities_pb2 as yamcs_dot_protobuf_dot_activities_dot_activities__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/timeline/timeline.proto',
  package='yamcs.protobuf.timeline',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\rTimelineProtoP\001',
  serialized_pb=b'\n&yamcs/protobuf/timeline/timeline.proto\x12\x17yamcs.protobuf.timeline\x1a\x1byamcs/api/annotations.proto\x1a*yamcs/protobuf/activities/activities.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"O\n\x0cRelativeTime\x12\r\n\x05relto\x18\x01 \x01(\t\x12\x30\n\rrelativeStart\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xd6\x04\n\x0cTimelineItem\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x37\n\x04type\x18\x03 \x01(\x0e\x32).yamcs.protobuf.timeline.TimelineItemType\x12)\n\x05start\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x08\x64uration\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0c\n\x04tags\x18\x06 \x03(\t\x12\x0f\n\x07groupId\x18\x07 \x01(\t\x12;\n\x0crelativeTime\x18\x08 \x01(\x0b\x32%.yamcs.protobuf.timeline.RelativeTime\x12\x13\n\x0b\x64\x65scription\x18\t \x01(\t\x12I\n\nproperties\x18\x0e \x03(\x0b\x32\x35.yamcs.protobuf.timeline.TimelineItem.PropertiesEntry\x12\x38\n\x06status\x18\n \x01(\x0e\x32(.yamcs.protobuf.timeline.ExecutionStatus\x12\x15\n\rfailureReason\x18\x0b \x01(\t\x12M\n\x12\x61\x63tivityDefinition\x18\r \x01(\x0b\x32\x31.yamcs.protobuf.activities.ActivityDefinitionInfo\x12\x0c\n\x04runs\x18\x0f \x03(\t\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n\x08LogEntry\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04user\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0b\n\x03msg\x18\x04 \x01(\t\"Q\n\x0fTimelineItemLog\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x07\x65ntries\x18\x02 \x03(\x0b\x32!.yamcs.protobuf.timeline.LogEntry\"\x80\x03\n\x0cTimelineBand\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08username\x18\x04 \x01(\t\x12\x0e\n\x06shared\x18\x05 \x01(\x08\x12\x0e\n\x06source\x18\x06 \x01(\t\x12\x10\n\x04tags\x18\x07 \x03(\tB\x02\x18\x01\x12\x34\n\x07\x66ilters\x18\x08 \x03(\x0b\x32#.yamcs.protobuf.timeline.ItemFilter\x12\x37\n\x04type\x18\t \x01(\x0e\x32).yamcs.protobuf.timeline.TimelineBandType\x12\x13\n\x0b\x64\x65scription\x18\n \x01(\t\x12I\n\nproperties\x18\x0b \x03(\x0b\x32\x35.yamcs.protobuf.timeline.TimelineBand.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x85\x01\n\x0cTimelineView\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x34\n\x05\x62\x61nds\x18\x05 \x03(\x0b\x32%.yamcs.protobuf.timeline.TimelineBand\"\xa3\x04\n\x11\x43reateItemRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\n\n\x02id\x18\r \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x37\n\x04type\x18\x04 \x01(\x0e\x32).yamcs.protobuf.timeline.TimelineItemType\x12)\n\x05start\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x08\x64uration\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0c\n\x04tags\x18\x07 \x03(\t\x12\x0f\n\x07groupId\x18\x08 \x01(\t\x12;\n\x0crelativeTime\x18\t \x01(\x0b\x32%.yamcs.protobuf.timeline.RelativeTime\x12\x13\n\x0b\x64\x65scription\x18\n \x01(\t\x12N\n\nproperties\x18\x0b \x03(\x0b\x32:.yamcs.protobuf.timeline.CreateItemRequest.PropertiesEntry\x12M\n\x12\x61\x63tivityDefinition\x18\x0c \x01(\x0b\x32\x31.yamcs.protobuf.activities.ActivityDefinitionInfo\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\">\n\x0eGetItemRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\"\x83\x04\n\x11UpdateItemRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12)\n\x05start\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x08\x64uration\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0c\n\x04tags\x18\x07 \x03(\t\x12\x11\n\tclearTags\x18\x08 \x01(\x08\x12\x0f\n\x07groupId\x18\t \x01(\t\x12;\n\x0crelativeTime\x18\n \x01(\x0b\x32%.yamcs.protobuf.timeline.RelativeTime\x12\x38\n\x06status\x18\x0b \x01(\x0e\x32(.yamcs.protobuf.timeline.ExecutionStatus\x12\x15\n\rfailureReason\x18\x0c \x01(\t\x12N\n\nproperties\x18\r \x03(\x0b\x32:.yamcs.protobuf.timeline.UpdateItemRequest.PropertiesEntry\x12\x17\n\x0f\x63learProperties\x18\x0e \x01(\x08\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfb\x01\n\x10ListItemsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\x0c\n\x04next\x18\x04 \x01(\t\x12)\n\x05start\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04\x62\x61nd\x18\x07 \x01(\t\x12\x34\n\x07\x66ilters\x18\x08 \x03(\x0b\x32#.yamcs.protobuf.timeline.ItemFilter\x12\x0f\n\x07\x64\x65tails\x18\t \x01(\x08\"A\n\x11\x44\x65leteItemRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\"A\n\x11GetItemLogRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\"s\n\x11\x41\x64\x64ItemLogRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x30\n\x05\x65ntry\x18\x04 \x01(\x0b\x32!.yamcs.protobuf.timeline.LogEntry\"J\n\x1a\x44\x65leteTimelineGroupRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\"t\n\x11ListItemsResponse\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x34\n\x05items\x18\x02 \x03(\x0b\x32%.yamcs.protobuf.timeline.TimelineItem\x12\x19\n\x11\x63ontinuationToken\x18\x03 \x01(\t\"\x9e\x01\n\x1aTimelineSourceCapabilities\x12\x10\n\x08readOnly\x18\x01 \x01(\x08\x12\x1b\n\x13hasManualActivities\x18\x02 \x01(\x08\x12\x1e\n\x16hasAutomatedActivities\x18\x03 \x01(\x08\x12\x16\n\x0ehasEventGroups\x18\x04 \x01(\x08\x12\x19\n\x11hasActivityGroups\x18\x05 \x01(\x08\"&\n\x12ListSourcesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"\xc6\x01\n\x13ListSourcesResponse\x12J\n\x07sources\x18\x01 \x03(\x0b\x32\x39.yamcs.protobuf.timeline.ListSourcesResponse.SourcesEntry\x1a\x63\n\x0cSourcesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x42\n\x05value\x18\x02 \x01(\x0b\x32\x33.yamcs.protobuf.timeline.TimelineSourceCapabilities:\x02\x38\x01\";\n\x17ListTimelineTagsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\"(\n\x18ListTimelineTagsResponse\x12\x0c\n\x04tags\x18\x01 \x03(\t\"\xf2\x02\n\x0e\x41\x64\x64\x42\x61ndRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\n\n\x02id\x18\n \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06shared\x18\x03 \x01(\x08\x12\x0e\n\x06source\x18\x04 \x01(\t\x12\x10\n\x04tags\x18\x05 \x03(\tB\x02\x18\x01\x12\x34\n\x07\x66ilters\x18\x06 \x03(\x0b\x32#.yamcs.protobuf.timeline.ItemFilter\x12\x37\n\x04type\x18\x07 \x01(\x0e\x32).yamcs.protobuf.timeline.TimelineBandType\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12K\n\nproperties\x18\t \x03(\x0b\x32\x37.yamcs.protobuf.timeline.AddBandRequest.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\".\n\x0eGetBandRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\"\xbb\x02\n\x11UpdateBandRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0e\n\x06shared\x18\x05 \x01(\x08\x12\x0c\n\x04tags\x18\x06 \x03(\t\x12N\n\nproperties\x18\x07 \x03(\x0b\x32:.yamcs.protobuf.timeline.UpdateBandRequest.PropertiesEntry\x12\x0e\n\x06source\x18\x08 \x01(\t\x12\x34\n\x07\x66ilters\x18\t \x03(\x0b\x32#.yamcs.protobuf.timeline.ItemFilter\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"$\n\x10ListBandsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"1\n\x11\x44\x65leteBandRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\"I\n\x11ListBandsResponse\x12\x34\n\x05\x62\x61nds\x18\x01 \x03(\x0b\x32%.yamcs.protobuf.timeline.TimelineBand\"`\n\x0e\x41\x64\x64ViewRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\r\n\x05\x62\x61nds\x18\x04 \x03(\t\".\n\x0eGetViewRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\"$\n\x10ListViewsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"c\n\x11UpdateViewRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\r\n\x05\x62\x61nds\x18\x05 \x03(\t\"1\n\x11\x44\x65leteViewRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\"I\n\x11ListViewsResponse\x12\x34\n\x05views\x18\x01 \x03(\x0b\x32%.yamcs.protobuf.timeline.TimelineView\"\x82\x01\n\nItemFilter\x12\x45\n\x08\x63riteria\x18\x01 \x03(\x0b\x32\x33.yamcs.protobuf.timeline.ItemFilter.FilterCriterion\x1a-\n\x0f\x46ilterCriterion\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t*O\n\x10TimelineItemType\x12\t\n\x05\x45VENT\x10\x01\x12\x0c\n\x08\x41\x43TIVITY\x10\x02\x12\x0e\n\nITEM_GROUP\x10\x04\x12\x12\n\x0e\x41\x43TIVITY_GROUP\x10\x05*W\n\x0f\x45xecutionStatus\x12\x0b\n\x07PLANNED\x10\x01\x12\x0f\n\x0bIN_PROGRESS\x10\x02\x12\r\n\tCOMPLETED\x10\x03\x12\x0b\n\x07\x41\x42ORTED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05*y\n\x10TimelineBandType\x12\x0e\n\nTIME_RULER\x10\x01\x12\r\n\tITEM_BAND\x10\x02\x12\n\n\x06SPACER\x10\x03\x12\x10\n\x0c\x43OMMAND_BAND\x10\x04\x12\x12\n\x0ePARAMETER_PLOT\x10\x05\x12\x14\n\x10PARAMETER_STATES\x10\x06\x32\x9a\x16\n\x0bTimelineApi\x12\x88\x01\n\nCreateItem\x12*.yamcs.protobuf.timeline.CreateItemRequest\x1a%.yamcs.protobuf.timeline.TimelineItem\"\'\x8a\x92\x03#\x1a\x1e/api/timeline/{instance}/items:\x01*\x12\x84\x01\n\x07GetItem\x12\'.yamcs.protobuf.timeline.GetItemRequest\x1a%.yamcs.protobuf.timeline.TimelineItem\")\x8a\x92\x03%\n#/api/timeline/{instance}/items/{id}\x12\x8d\x01\n\nUpdateItem\x12*.yamcs.protobuf.timeline.UpdateItemRequest\x1a%.yamcs.protobuf.timeline.TimelineItem\",\x8a\x92\x03(\x12#/api/timeline/{instance}/items/{id}:\x01*\x12\x88\x01\n\tListItems\x12).yamcs.protobuf.timeline.ListItemsRequest\x1a*.yamcs.protobuf.timeline.ListItemsResponse\"$\x8a\x92\x03 \n\x1e/api/timeline/{instance}/items\x12\x8a\x01\n\nDeleteItem\x12*.yamcs.protobuf.timeline.DeleteItemRequest\x1a%.yamcs.protobuf.timeline.TimelineItem\")\x8a\x92\x03%\"#/api/timeline/{instance}/items/{id}\x12\x91\x01\n\nGetItemLog\x12*.yamcs.protobuf.timeline.GetItemLogRequest\x1a(.yamcs.protobuf.timeline.TimelineItemLog\"-\x8a\x92\x03)\n\'/api/timeline/{instance}/items/{id}/log\x12\x8a\x01\n\nAddItemLog\x12*.yamcs.protobuf.timeline.AddItemLogRequest\x1a!.yamcs.protobuf.timeline.LogEntry\"-\x8a\x92\x03)\x1a\'/api/timeline/{instance}/items/{id}/log\x12\x9d\x01\n\x13\x44\x65leteTimelineGroup\x12\x33.yamcs.protobuf.timeline.DeleteTimelineGroupRequest\x1a%.yamcs.protobuf.timeline.TimelineItem\"*\x8a\x92\x03&\"$/api/timeline/{instance}/groups/{id}\x12\x90\x01\n\x0bListSources\x12+.yamcs.protobuf.timeline.ListSourcesRequest\x1a,.yamcs.protobuf.timeline.ListSourcesResponse\"&\x8a\x92\x03\"\n /api/timeline/{instance}/sources\x12\x94\x01\n\x08ListTags\x12\x30.yamcs.protobuf.timeline.ListTimelineTagsRequest\x1a\x31.yamcs.protobuf.timeline.ListTimelineTagsResponse\"#\x8a\x92\x03\x1f\n\x1d/api/timeline/{instance}/tags\x12\x82\x01\n\x07\x41\x64\x64\x42\x61nd\x12\'.yamcs.protobuf.timeline.AddBandRequest\x1a%.yamcs.protobuf.timeline.TimelineBand\"\'\x8a\x92\x03#\x1a\x1e/api/timeline/{instance}/bands:\x01*\x12\x84\x01\n\x07GetBand\x12\'.yamcs.protobuf.timeline.GetBandRequest\x1a%.yamcs.protobuf.timeline.TimelineBand\")\x8a\x92\x03%\n#/api/timeline/{instance}/bands/{id}\x12\x88\x01\n\tListBands\x12).yamcs.protobuf.timeline.ListBandsRequest\x1a*.yamcs.protobuf.timeline.ListBandsResponse\"$\x8a\x92\x03 \n\x1e/api/timeline/{instance}/bands\x12\x8d\x01\n\nUpdateBand\x12*.yamcs.protobuf.timeline.UpdateBandRequest\x1a%.yamcs.protobuf.timeline.TimelineBand\",\x8a\x92\x03(\x12#/api/timeline/{instance}/bands/{id}:\x01*\x12\x8a\x01\n\nDeleteBand\x12*.yamcs.protobuf.timeline.DeleteBandRequest\x1a%.yamcs.protobuf.timeline.TimelineBand\")\x8a\x92\x03%\"#/api/timeline/{instance}/bands/{id}\x12\x82\x01\n\x07\x41\x64\x64View\x12\'.yamcs.protobuf.timeline.AddViewRequest\x1a%.yamcs.protobuf.timeline.TimelineView\"\'\x8a\x92\x03#\x1a\x1e/api/timeline/{instance}/views:\x01*\x12\x84\x01\n\x07GetView\x12\'.yamcs.protobuf.timeline.GetViewRequest\x1a%.yamcs.protobuf.timeline.TimelineView\")\x8a\x92\x03%\n#/api/timeline/{instance}/views/{id}\x12\x88\x01\n\tListViews\x12).yamcs.protobuf.timeline.ListViewsRequest\x1a*.yamcs.protobuf.timeline.ListViewsResponse\"$\x8a\x92\x03 \n\x1e/api/timeline/{instance}/views\x12\x8d\x01\n\nUpdateView\x12*.yamcs.protobuf.timeline.UpdateViewRequest\x1a%.yamcs.protobuf.timeline.TimelineView\",\x8a\x92\x03(\x12#/api/timeline/{instance}/views/{id}:\x01*\x12\x8a\x01\n\nDeleteView\x12*.yamcs.protobuf.timeline.DeleteViewRequest\x1a%.yamcs.protobuf.timeline.TimelineView\")\x8a\x92\x03%\"#/api/timeline/{instance}/views/{id}B%\n\x12org.yamcs.protobufB\rTimelineProtoP\x01'
  ,
  dependencies=[yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_activities_dot_activities__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,])

_TIMELINEITEMTYPE = _descriptor.EnumDescriptor(
  name='TimelineItemType',
  full_name='yamcs.protobuf.timeline.TimelineItemType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EVENT', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTIVITY', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_GROUP', index=2, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTIVITY_GROUP', index=3, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5371,
  serialized_end=5450,
)
_sym_db.RegisterEnumDescriptor(_TIMELINEITEMTYPE)

TimelineItemType = enum_type_wrapper.EnumTypeWrapper(_TIMELINEITEMTYPE)
_EXECUTIONSTATUS = _descriptor.EnumDescriptor(
  name='ExecutionStatus',
  full_name='yamcs.protobuf.timeline.ExecutionStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PLANNED', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IN_PROGRESS', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPLETED', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ABORTED', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=4, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5452,
  serialized_end=5539,
)
_sym_db.RegisterEnumDescriptor(_EXECUTIONSTATUS)

ExecutionStatus = enum_type_wrapper.EnumTypeWrapper(_EXECUTIONSTATUS)
_TIMELINEBANDTYPE = _descriptor.EnumDescriptor(
  name='TimelineBandType',
  full_name='yamcs.protobuf.timeline.TimelineBandType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TIME_RULER', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_BAND', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SPACER', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMAND_BAND', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARAMETER_PLOT', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARAMETER_STATES', index=5, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5541,
  serialized_end=5662,
)
_sym_db.RegisterEnumDescriptor(_TIMELINEBANDTYPE)

TimelineBandType = enum_type_wrapper.EnumTypeWrapper(_TIMELINEBANDTYPE)
EVENT = 1
ACTIVITY = 2
ITEM_GROUP = 4
ACTIVITY_GROUP = 5
PLANNED = 1
IN_PROGRESS = 2
COMPLETED = 3
ABORTED = 4
FAILED = 5
TIME_RULER = 1
ITEM_BAND = 2
SPACER = 3
COMMAND_BAND = 4
PARAMETER_PLOT = 5
PARAMETER_STATES = 6



_RELATIVETIME = _descriptor.Descriptor(
  name='RelativeTime',
  full_name='yamcs.protobuf.timeline.RelativeTime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='relto', full_name='yamcs.protobuf.timeline.RelativeTime.relto', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relativeStart', full_name='yamcs.protobuf.timeline.RelativeTime.relativeStart', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=284,
)


_TIMELINEITEM_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='yamcs.protobuf.timeline.TimelineItem.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.timeline.TimelineItem.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.timeline.TimelineItem.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=836,
  serialized_end=885,
)

_TIMELINEITEM = _descriptor.Descriptor(
  name='TimelineItem',
  full_name='yamcs.protobuf.timeline.TimelineItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.timeline.TimelineItem.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.timeline.TimelineItem.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.timeline.TimelineItem.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.timeline.TimelineItem.start', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='yamcs.protobuf.timeline.TimelineItem.duration', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='yamcs.protobuf.timeline.TimelineItem.tags', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groupId', full_name='yamcs.protobuf.timeline.TimelineItem.groupId', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relativeTime', full_name='yamcs.protobuf.timeline.TimelineItem.relativeTime', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.timeline.TimelineItem.description', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='properties', full_name='yamcs.protobuf.timeline.TimelineItem.properties', index=9,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='yamcs.protobuf.timeline.TimelineItem.status', index=10,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failureReason', full_name='yamcs.protobuf.timeline.TimelineItem.failureReason', index=11,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activityDefinition', full_name='yamcs.protobuf.timeline.TimelineItem.activityDefinition', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='runs', full_name='yamcs.protobuf.timeline.TimelineItem.runs', index=13,
      number=15, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TIMELINEITEM_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=287,
  serialized_end=885,
)


_LOGENTRY = _descriptor.Descriptor(
  name='LogEntry',
  full_name='yamcs.protobuf.timeline.LogEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='yamcs.protobuf.timeline.LogEntry.time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user', full_name='yamcs.protobuf.timeline.LogEntry.user', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.timeline.LogEntry.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg', full_name='yamcs.protobuf.timeline.LogEntry.msg', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=887,
  serialized_end=980,
)


_TIMELINEITEMLOG = _descriptor.Descriptor(
  name='TimelineItemLog',
  full_name='yamcs.protobuf.timeline.TimelineItemLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.timeline.TimelineItemLog.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entries', full_name='yamcs.protobuf.timeline.TimelineItemLog.entries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=982,
  serialized_end=1063,
)


_TIMELINEBAND_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='yamcs.protobuf.timeline.TimelineBand.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.timeline.TimelineBand.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.timeline.TimelineBand.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=836,
  serialized_end=885,
)

_TIMELINEBAND = _descriptor.Descriptor(
  name='TimelineBand',
  full_name='yamcs.protobuf.timeline.TimelineBand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.timeline.TimelineBand.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.timeline.TimelineBand.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.timeline.TimelineBand.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='yamcs.protobuf.timeline.TimelineBand.username', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shared', full_name='yamcs.protobuf.timeline.TimelineBand.shared', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.timeline.TimelineBand.source', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='yamcs.protobuf.timeline.TimelineBand.tags', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filters', full_name='yamcs.protobuf.timeline.TimelineBand.filters', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.timeline.TimelineBand.type', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.timeline.TimelineBand.description', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='properties', full_name='yamcs.protobuf.timeline.TimelineBand.properties', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TIMELINEBAND_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1066,
  serialized_end=1450,
)


_TIMELINEVIEW = _descriptor.Descriptor(
  name='TimelineView',
  full_name='yamcs.protobuf.timeline.TimelineView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.timeline.TimelineView.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.timeline.TimelineView.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.timeline.TimelineView.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.timeline.TimelineView.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bands', full_name='yamcs.protobuf.timeline.TimelineView.bands', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1453,
  serialized_end=1586,
)


_CREATEITEMREQUEST_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='yamcs.protobuf.timeline.CreateItemRequest.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.timeline.CreateItemRequest.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.timeline.CreateItemRequest.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=836,
  serialized_end=885,
)

_CREATEITEMREQUEST = _descriptor.Descriptor(
  name='CreateItemRequest',
  full_name='yamcs.protobuf.timeline.CreateItemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.timeline.CreateItemRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.timeline.CreateItemRequest.source', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.timeline.CreateItemRequest.id', index=2,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.timeline.CreateItemRequest.name', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.timeline.CreateItemRequest.type', index=4,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.timeline.CreateItemRequest.start', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='yamcs.protobuf.timeline.CreateItemRequest.duration', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='yamcs.protobuf.timeline.CreateItemRequest.tags', index=7,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groupId', full_name='yamcs.protobuf.timeline.CreateItemRequest.groupId', index=8,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relativeTime', full_name='yamcs.protobuf.timeline.CreateItemRequest.relativeTime', index=9,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.timeline.CreateItemRequest.description', index=10,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='properties', full_name='yamcs.protobuf.timeline.CreateItemRequest.properties', index=11,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activityDefinition', full_name='yamcs.protobuf.timeline.CreateItemRequest.activityDefinition', index=12,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CREATEITEMREQUEST_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1589,
  serialized_end=2136,
)


_GETITEMREQUEST = _descriptor.Descriptor(
  name='GetItemRequest',
  full_name='yamcs.protobuf.timeline.GetItemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.timeline.GetItemRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.timeline.GetItemRequest.source', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.timeline.GetItemRequest.id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2138,
  serialized_end=2200,
)


_UPDATEITEMREQUEST_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='yamcs.protobuf.timeline.UpdateItemRequest.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.timeline.UpdateItemRequest.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.timeline.UpdateItemRequest.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=836,
  serialized_end=885,
)

_UPDATEITEMREQUEST = _descriptor.Descriptor(
  name='UpdateItemRequest',
  full_name='yamcs.protobuf.timeline.UpdateItemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.timeline.UpdateItemRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.timeline.UpdateItemRequest.source', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.timeline.UpdateItemRequest.id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.timeline.UpdateItemRequest.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.timeline.UpdateItemRequest.start', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='yamcs.protobuf.timeline.UpdateItemRequest.duration', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='yamcs.protobuf.timeline.UpdateItemRequest.tags', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clearTags', full_name='yamcs.protobuf.timeline.UpdateItemRequest.clearTags', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groupId', full_name='yamcs.protobuf.timeline.UpdateItemRequest.groupId', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relativeTime', full_name='yamcs.protobuf.timeline.UpdateItemRequest.relativeTime', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='yamcs.protobuf.timeline.UpdateItemRequest.status', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failureReason', full_name='yamcs.protobuf.timeline.UpdateItemRequest.failureReason', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='properties', full_name='yamcs.protobuf.timeline.UpdateItemRequest.properties', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clearProperties', full_name='yamcs.protobuf.timeline.UpdateItemRequest.clearProperties', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEITEMREQUEST_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2203,
  serialized_end=2718,
)


_LISTITEMSREQUEST = _descriptor.Descriptor(
  name='ListItemsRequest',
  full_name='yamcs.protobuf.timeline.ListItemsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.timeline.ListItemsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.timeline.ListItemsRequest.source', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.timeline.ListItemsRequest.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.timeline.ListItemsRequest.next', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.timeline.ListItemsRequest.start', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.timeline.ListItemsRequest.stop', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='band', full_name='yamcs.protobuf.timeline.ListItemsRequest.band', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filters', full_name='yamcs.protobuf.timeline.ListItemsRequest.filters', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='details', full_name='yamcs.protobuf.timeline.ListItemsRequest.details', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2721,
  serialized_end=2972,
)


_DELETEITEMREQUEST = _descriptor.Descriptor(
  name='DeleteItemRequest',
  full_name='yamcs.protobuf.timeline.DeleteItemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.timeline.DeleteItemRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.timeline.DeleteItemRequest.source', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.timeline.DeleteItemRequest.id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2974,
  serialized_end=3039,
)


_GETITEMLOGREQUEST = _descriptor.Descriptor(
  name='GetItemLogRequest',
  full_name='yamcs.protobuf.timeline.GetItemLogRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.timeline.GetItemLogRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.timeline.GetItemLogRequest.source', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.timeline.GetItemLogRequest.id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3041,
  serialized_end=3106,
)


_ADDITEMLOGREQUEST = _descriptor.Descriptor(
  name='AddItemLogRequest',
  full_name='yamcs.protobuf.timeline.AddItemLogRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.timeline.AddItemLogRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.timeline.AddItemLogRequest.source', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.timeline.AddItemLogRequest.id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entry', full_name='yamcs.protobuf.timeline.AddItemLogRequest.entry', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3108,
  serialized_end=3223,
)


_DELETETIMELINEGROUPREQUEST = _descriptor.Descriptor(
  name='DeleteTimelineGroupRequest',
  full_name='yamcs.protobuf.timeline.DeleteTimelineGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.timeline.DeleteTimelineGroupRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.timeline.DeleteTimelineGroupRequest.source', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.timeline.DeleteTimelineGroupRequest.id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3225,
  serialized_end=3299,
)


_LISTITEMSRESPONSE = _descriptor.Descriptor(
  name='ListItemsResponse',
  full_name='yamcs.protobuf.timeline.ListItemsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.timeline.ListItemsResponse.source', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='items', full_name='yamcs.protobuf.timeline.ListItemsResponse.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.timeline.ListItemsResponse.continuationToken', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3301,
  serialized_end=3417,
)


_TIMELINESOURCECAPABILITIES = _descriptor.Descriptor(
  name='TimelineSourceCapabilities',
  full_name='yamcs.protobuf.timeline.TimelineSourceCapabilities',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='yamcs.protobuf.timeline.TimelineSourceCapabilities.readOnly', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hasManualActivities', full_name='yamcs.protobuf.timeline.TimelineSourceCapabilities.hasManualActivities', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hasAutomatedActivities', full_name='yamcs.protobuf.timeline.TimelineSourceCapabilities.hasAutomatedActivities', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hasEventGroups', full_name='yamcs.protobuf.timeline.TimelineSourceCapabilities.hasEventGroups', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hasActivityGroups', full_name='yamcs.protobuf.timeline.TimelineSourceCapabilities.hasActivityGroups', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3420,
  serialized_end=3578,
)


_LISTSOURCESREQUEST = _descriptor.Descriptor(
  name='ListSourcesRequest',
  full_name='yamcs.protobuf.timeline.ListSourcesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.timeline.ListSourcesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3580,
  serialized_end=3618,
)


_LISTSOURCESRESPONSE_SOURCESENTRY = _descriptor.Descriptor(
  name='SourcesEntry',
  full_name='yamcs.protobuf.timeline.ListSourcesResponse.SourcesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.timeline.ListSourcesResponse.SourcesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.timeline.ListSourcesResponse.SourcesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3720,
  serialized_end=3819,
)

_LISTSOURCESRESPONSE = _descriptor.Descriptor(
  name='ListSourcesResponse',
  full_name='yamcs.protobuf.timeline.ListSourcesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sources', full_name='yamcs.protobuf.timeline.ListSourcesResponse.sources', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LISTSOURCESRESPONSE_SOURCESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3621,
  serialized_end=3819,
)


_LISTTIMELINETAGSREQUEST = _descriptor.Descriptor(
  name='ListTimelineTagsRequest',
  full_name='yamcs.protobuf.timeline.ListTimelineTagsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.timeline.ListTimelineTagsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.timeline.ListTimelineTagsRequest.source', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3821,
  serialized_end=3880,
)


_LISTTIMELINETAGSRESPONSE = _descriptor.Descriptor(
  name='ListTimelineTagsResponse',
  full_name='yamcs.protobuf.timeline.ListTimelineTagsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tags', full_name='yamcs.protobuf.timeline.ListTimelineTagsResponse.tags', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3882,
  serialized_end=3922,
)


_ADDBANDREQUEST_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='yamcs.protobuf.timeline.AddBandRequest.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.timeline.AddBandRequest.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.timeline.AddBandRequest.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=836,
  serialized_end=885,
)

_ADDBANDREQUEST = _descriptor.Descriptor(
  name='AddBandRequest',
  full_name='yamcs.protobuf.timeline.AddBandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.timeline.AddBandRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.timeline.AddBandRequest.id', index=1,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.timeline.AddBandRequest.name', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shared', full_name='yamcs.protobuf.timeline.AddBandRequest.shared', index=3,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.timeline.AddBandRequest.source', index=4,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='yamcs.protobuf.timeline.AddBandRequest.tags', index=5,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filters', full_name='yamcs.protobuf.timeline.AddBandRequest.filters', index=6,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.timeline.AddBandRequest.type', index=7,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.timeline.AddBandRequest.description', index=8,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='properties', full_name='yamcs.protobuf.timeline.AddBandRequest.properties', index=9,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ADDBANDREQUEST_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3925,
  serialized_end=4295,
)


_GETBANDREQUEST = _descriptor.Descriptor(
  name='GetBandRequest',
  full_name='yamcs.protobuf.timeline.GetBandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.timeline.GetBandRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.timeline.GetBandRequest.id', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4297,
  serialized_end=4343,
)


_UPDATEBANDREQUEST_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='yamcs.protobuf.timeline.UpdateBandRequest.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.timeline.UpdateBandRequest.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.timeline.UpdateBandRequest.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=836,
  serialized_end=885,
)

_UPDATEBANDREQUEST = _descriptor.Descriptor(
  name='UpdateBandRequest',
  full_name='yamcs.protobuf.timeline.UpdateBandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.timeline.UpdateBandRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.timeline.UpdateBandRequest.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.timeline.UpdateBandRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.timeline.UpdateBandRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shared', full_name='yamcs.protobuf.timeline.UpdateBandRequest.shared', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='yamcs.protobuf.timeline.UpdateBandRequest.tags', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='properties', full_name='yamcs.protobuf.timeline.UpdateBandRequest.properties', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.timeline.UpdateBandRequest.source', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filters', full_name='yamcs.protobuf.timeline.UpdateBandRequest.filters', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEBANDREQUEST_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4346,
  serialized_end=4661,
)


_LISTBANDSREQUEST = _descriptor.Descriptor(
  name='ListBandsRequest',
  full_name='yamcs.protobuf.timeline.ListBandsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.timeline.ListBandsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4663,
  serialized_end=4699,
)


_DELETEBANDREQUEST = _descriptor.Descriptor(
  name='DeleteBandRequest',
  full_name='yamcs.protobuf.timeline.DeleteBandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.timeline.DeleteBandRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.timeline.DeleteBandRequest.id', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4701,
  serialized_end=4750,
)


_LISTBANDSRESPONSE = _descriptor.Descriptor(
  name='ListBandsResponse',
  full_name='yamcs.protobuf.timeline.ListBandsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bands', full_name='yamcs.protobuf.timeline.ListBandsResponse.bands', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4752,
  serialized_end=4825,
)


_ADDVIEWREQUEST = _descriptor.Descriptor(
  name='AddViewRequest',
  full_name='yamcs.protobuf.timeline.AddViewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.timeline.AddViewRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.timeline.AddViewRequest.id', index=1,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.timeline.AddViewRequest.name', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.timeline.AddViewRequest.description', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bands', full_name='yamcs.protobuf.timeline.AddViewRequest.bands', index=4,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4827,
  serialized_end=4923,
)


_GETVIEWREQUEST = _descriptor.Descriptor(
  name='GetViewRequest',
  full_name='yamcs.protobuf.timeline.GetViewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.timeline.GetViewRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.timeline.GetViewRequest.id', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4925,
  serialized_end=4971,
)


_LISTVIEWSREQUEST = _descriptor.Descriptor(
  name='ListViewsRequest',
  full_name='yamcs.protobuf.timeline.ListViewsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.timeline.ListViewsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4973,
  serialized_end=5009,
)


_UPDATEVIEWREQUEST = _descriptor.Descriptor(
  name='UpdateViewRequest',
  full_name='yamcs.protobuf.timeline.UpdateViewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.timeline.UpdateViewRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.timeline.UpdateViewRequest.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.timeline.UpdateViewRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.timeline.UpdateViewRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bands', full_name='yamcs.protobuf.timeline.UpdateViewRequest.bands', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5011,
  serialized_end=5110,
)


_DELETEVIEWREQUEST = _descriptor.Descriptor(
  name='DeleteViewRequest',
  full_name='yamcs.protobuf.timeline.DeleteViewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.timeline.DeleteViewRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.timeline.DeleteViewRequest.id', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5112,
  serialized_end=5161,
)


_LISTVIEWSRESPONSE = _descriptor.Descriptor(
  name='ListViewsResponse',
  full_name='yamcs.protobuf.timeline.ListViewsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='views', full_name='yamcs.protobuf.timeline.ListViewsResponse.views', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5163,
  serialized_end=5236,
)


_ITEMFILTER_FILTERCRITERION = _descriptor.Descriptor(
  name='FilterCriterion',
  full_name='yamcs.protobuf.timeline.ItemFilter.FilterCriterion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.timeline.ItemFilter.FilterCriterion.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.timeline.ItemFilter.FilterCriterion.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5324,
  serialized_end=5369,
)

_ITEMFILTER = _descriptor.Descriptor(
  name='ItemFilter',
  full_name='yamcs.protobuf.timeline.ItemFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='criteria', full_name='yamcs.protobuf.timeline.ItemFilter.criteria', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ITEMFILTER_FILTERCRITERION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5239,
  serialized_end=5369,
)

_RELATIVETIME.fields_by_name['relativeStart'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TIMELINEITEM_PROPERTIESENTRY.containing_type = _TIMELINEITEM
_TIMELINEITEM.fields_by_name['type'].enum_type = _TIMELINEITEMTYPE
_TIMELINEITEM.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TIMELINEITEM.fields_by_name['duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TIMELINEITEM.fields_by_name['relativeTime'].message_type = _RELATIVETIME
_TIMELINEITEM.fields_by_name['properties'].message_type = _TIMELINEITEM_PROPERTIESENTRY
_TIMELINEITEM.fields_by_name['status'].enum_type = _EXECUTIONSTATUS
_TIMELINEITEM.fields_by_name['activityDefinition'].message_type = yamcs_dot_protobuf_dot_activities_dot_activities__pb2._ACTIVITYDEFINITIONINFO
_LOGENTRY.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TIMELINEITEMLOG.fields_by_name['entries'].message_type = _LOGENTRY
_TIMELINEBAND_PROPERTIESENTRY.containing_type = _TIMELINEBAND
_TIMELINEBAND.fields_by_name['filters'].message_type = _ITEMFILTER
_TIMELINEBAND.fields_by_name['type'].enum_type = _TIMELINEBANDTYPE
_TIMELINEBAND.fields_by_name['properties'].message_type = _TIMELINEBAND_PROPERTIESENTRY
_TIMELINEVIEW.fields_by_name['bands'].message_type = _TIMELINEBAND
_CREATEITEMREQUEST_PROPERTIESENTRY.containing_type = _CREATEITEMREQUEST
_CREATEITEMREQUEST.fields_by_name['type'].enum_type = _TIMELINEITEMTYPE
_CREATEITEMREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CREATEITEMREQUEST.fields_by_name['duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CREATEITEMREQUEST.fields_by_name['relativeTime'].message_type = _RELATIVETIME
_CREATEITEMREQUEST.fields_by_name['properties'].message_type = _CREATEITEMREQUEST_PROPERTIESENTRY
_CREATEITEMREQUEST.fields_by_name['activityDefinition'].message_type = yamcs_dot_protobuf_dot_activities_dot_activities__pb2._ACTIVITYDEFINITIONINFO
_UPDATEITEMREQUEST_PROPERTIESENTRY.containing_type = _UPDATEITEMREQUEST
_UPDATEITEMREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_UPDATEITEMREQUEST.fields_by_name['duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_UPDATEITEMREQUEST.fields_by_name['relativeTime'].message_type = _RELATIVETIME
_UPDATEITEMREQUEST.fields_by_name['status'].enum_type = _EXECUTIONSTATUS
_UPDATEITEMREQUEST.fields_by_name['properties'].message_type = _UPDATEITEMREQUEST_PROPERTIESENTRY
_LISTITEMSREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTITEMSREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTITEMSREQUEST.fields_by_name['filters'].message_type = _ITEMFILTER
_ADDITEMLOGREQUEST.fields_by_name['entry'].message_type = _LOGENTRY
_LISTITEMSRESPONSE.fields_by_name['items'].message_type = _TIMELINEITEM
_LISTSOURCESRESPONSE_SOURCESENTRY.fields_by_name['value'].message_type = _TIMELINESOURCECAPABILITIES
_LISTSOURCESRESPONSE_SOURCESENTRY.containing_type = _LISTSOURCESRESPONSE
_LISTSOURCESRESPONSE.fields_by_name['sources'].message_type = _LISTSOURCESRESPONSE_SOURCESENTRY
_ADDBANDREQUEST_PROPERTIESENTRY.containing_type = _ADDBANDREQUEST
_ADDBANDREQUEST.fields_by_name['filters'].message_type = _ITEMFILTER
_ADDBANDREQUEST.fields_by_name['type'].enum_type = _TIMELINEBANDTYPE
_ADDBANDREQUEST.fields_by_name['properties'].message_type = _ADDBANDREQUEST_PROPERTIESENTRY
_UPDATEBANDREQUEST_PROPERTIESENTRY.containing_type = _UPDATEBANDREQUEST
_UPDATEBANDREQUEST.fields_by_name['properties'].message_type = _UPDATEBANDREQUEST_PROPERTIESENTRY
_UPDATEBANDREQUEST.fields_by_name['filters'].message_type = _ITEMFILTER
_LISTBANDSRESPONSE.fields_by_name['bands'].message_type = _TIMELINEBAND
_LISTVIEWSRESPONSE.fields_by_name['views'].message_type = _TIMELINEVIEW
_ITEMFILTER_FILTERCRITERION.containing_type = _ITEMFILTER
_ITEMFILTER.fields_by_name['criteria'].message_type = _ITEMFILTER_FILTERCRITERION
DESCRIPTOR.message_types_by_name['RelativeTime'] = _RELATIVETIME
DESCRIPTOR.message_types_by_name['TimelineItem'] = _TIMELINEITEM
DESCRIPTOR.message_types_by_name['LogEntry'] = _LOGENTRY
DESCRIPTOR.message_types_by_name['TimelineItemLog'] = _TIMELINEITEMLOG
DESCRIPTOR.message_types_by_name['TimelineBand'] = _TIMELINEBAND
DESCRIPTOR.message_types_by_name['TimelineView'] = _TIMELINEVIEW
DESCRIPTOR.message_types_by_name['CreateItemRequest'] = _CREATEITEMREQUEST
DESCRIPTOR.message_types_by_name['GetItemRequest'] = _GETITEMREQUEST
DESCRIPTOR.message_types_by_name['UpdateItemRequest'] = _UPDATEITEMREQUEST
DESCRIPTOR.message_types_by_name['ListItemsRequest'] = _LISTITEMSREQUEST
DESCRIPTOR.message_types_by_name['DeleteItemRequest'] = _DELETEITEMREQUEST
DESCRIPTOR.message_types_by_name['GetItemLogRequest'] = _GETITEMLOGREQUEST
DESCRIPTOR.message_types_by_name['AddItemLogRequest'] = _ADDITEMLOGREQUEST
DESCRIPTOR.message_types_by_name['DeleteTimelineGroupRequest'] = _DELETETIMELINEGROUPREQUEST
DESCRIPTOR.message_types_by_name['ListItemsResponse'] = _LISTITEMSRESPONSE
DESCRIPTOR.message_types_by_name['TimelineSourceCapabilities'] = _TIMELINESOURCECAPABILITIES
DESCRIPTOR.message_types_by_name['ListSourcesRequest'] = _LISTSOURCESREQUEST
DESCRIPTOR.message_types_by_name['ListSourcesResponse'] = _LISTSOURCESRESPONSE
DESCRIPTOR.message_types_by_name['ListTimelineTagsRequest'] = _LISTTIMELINETAGSREQUEST
DESCRIPTOR.message_types_by_name['ListTimelineTagsResponse'] = _LISTTIMELINETAGSRESPONSE
DESCRIPTOR.message_types_by_name['AddBandRequest'] = _ADDBANDREQUEST
DESCRIPTOR.message_types_by_name['GetBandRequest'] = _GETBANDREQUEST
DESCRIPTOR.message_types_by_name['UpdateBandRequest'] = _UPDATEBANDREQUEST
DESCRIPTOR.message_types_by_name['ListBandsRequest'] = _LISTBANDSREQUEST
DESCRIPTOR.message_types_by_name['DeleteBandRequest'] = _DELETEBANDREQUEST
DESCRIPTOR.message_types_by_name['ListBandsResponse'] = _LISTBANDSRESPONSE
DESCRIPTOR.message_types_by_name['AddViewRequest'] = _ADDVIEWREQUEST
DESCRIPTOR.message_types_by_name['GetViewRequest'] = _GETVIEWREQUEST
DESCRIPTOR.message_types_by_name['ListViewsRequest'] = _LISTVIEWSREQUEST
DESCRIPTOR.message_types_by_name['UpdateViewRequest'] = _UPDATEVIEWREQUEST
DESCRIPTOR.message_types_by_name['DeleteViewRequest'] = _DELETEVIEWREQUEST
DESCRIPTOR.message_types_by_name['ListViewsResponse'] = _LISTVIEWSRESPONSE
DESCRIPTOR.message_types_by_name['ItemFilter'] = _ITEMFILTER
DESCRIPTOR.enum_types_by_name['TimelineItemType'] = _TIMELINEITEMTYPE
DESCRIPTOR.enum_types_by_name['ExecutionStatus'] = _EXECUTIONSTATUS
DESCRIPTOR.enum_types_by_name['TimelineBandType'] = _TIMELINEBANDTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RelativeTime = _reflection.GeneratedProtocolMessageType('RelativeTime', (_message.Message,), {
  'DESCRIPTOR' : _RELATIVETIME,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.RelativeTime)
  })
_sym_db.RegisterMessage(RelativeTime)

TimelineItem = _reflection.GeneratedProtocolMessageType('TimelineItem', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _TIMELINEITEM_PROPERTIESENTRY,
    '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.TimelineItem.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _TIMELINEITEM,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.TimelineItem)
  })
_sym_db.RegisterMessage(TimelineItem)
_sym_db.RegisterMessage(TimelineItem.PropertiesEntry)

LogEntry = _reflection.GeneratedProtocolMessageType('LogEntry', (_message.Message,), {
  'DESCRIPTOR' : _LOGENTRY,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.LogEntry)
  })
_sym_db.RegisterMessage(LogEntry)

TimelineItemLog = _reflection.GeneratedProtocolMessageType('TimelineItemLog', (_message.Message,), {
  'DESCRIPTOR' : _TIMELINEITEMLOG,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.TimelineItemLog)
  })
_sym_db.RegisterMessage(TimelineItemLog)

TimelineBand = _reflection.GeneratedProtocolMessageType('TimelineBand', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _TIMELINEBAND_PROPERTIESENTRY,
    '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.TimelineBand.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _TIMELINEBAND,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.TimelineBand)
  })
_sym_db.RegisterMessage(TimelineBand)
_sym_db.RegisterMessage(TimelineBand.PropertiesEntry)

TimelineView = _reflection.GeneratedProtocolMessageType('TimelineView', (_message.Message,), {
  'DESCRIPTOR' : _TIMELINEVIEW,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.TimelineView)
  })
_sym_db.RegisterMessage(TimelineView)

CreateItemRequest = _reflection.GeneratedProtocolMessageType('CreateItemRequest', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEITEMREQUEST_PROPERTIESENTRY,
    '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.CreateItemRequest.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEITEMREQUEST,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.CreateItemRequest)
  })
_sym_db.RegisterMessage(CreateItemRequest)
_sym_db.RegisterMessage(CreateItemRequest.PropertiesEntry)

GetItemRequest = _reflection.GeneratedProtocolMessageType('GetItemRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETITEMREQUEST,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.GetItemRequest)
  })
_sym_db.RegisterMessage(GetItemRequest)

UpdateItemRequest = _reflection.GeneratedProtocolMessageType('UpdateItemRequest', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEITEMREQUEST_PROPERTIESENTRY,
    '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.UpdateItemRequest.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEITEMREQUEST,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.UpdateItemRequest)
  })
_sym_db.RegisterMessage(UpdateItemRequest)
_sym_db.RegisterMessage(UpdateItemRequest.PropertiesEntry)

ListItemsRequest = _reflection.GeneratedProtocolMessageType('ListItemsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTITEMSREQUEST,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.ListItemsRequest)
  })
_sym_db.RegisterMessage(ListItemsRequest)

DeleteItemRequest = _reflection.GeneratedProtocolMessageType('DeleteItemRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEITEMREQUEST,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.DeleteItemRequest)
  })
_sym_db.RegisterMessage(DeleteItemRequest)

GetItemLogRequest = _reflection.GeneratedProtocolMessageType('GetItemLogRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETITEMLOGREQUEST,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.GetItemLogRequest)
  })
_sym_db.RegisterMessage(GetItemLogRequest)

AddItemLogRequest = _reflection.GeneratedProtocolMessageType('AddItemLogRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDITEMLOGREQUEST,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.AddItemLogRequest)
  })
_sym_db.RegisterMessage(AddItemLogRequest)

DeleteTimelineGroupRequest = _reflection.GeneratedProtocolMessageType('DeleteTimelineGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETIMELINEGROUPREQUEST,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.DeleteTimelineGroupRequest)
  })
_sym_db.RegisterMessage(DeleteTimelineGroupRequest)

ListItemsResponse = _reflection.GeneratedProtocolMessageType('ListItemsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTITEMSRESPONSE,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.ListItemsResponse)
  })
_sym_db.RegisterMessage(ListItemsResponse)

TimelineSourceCapabilities = _reflection.GeneratedProtocolMessageType('TimelineSourceCapabilities', (_message.Message,), {
  'DESCRIPTOR' : _TIMELINESOURCECAPABILITIES,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.TimelineSourceCapabilities)
  })
_sym_db.RegisterMessage(TimelineSourceCapabilities)

ListSourcesRequest = _reflection.GeneratedProtocolMessageType('ListSourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSOURCESREQUEST,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.ListSourcesRequest)
  })
_sym_db.RegisterMessage(ListSourcesRequest)

ListSourcesResponse = _reflection.GeneratedProtocolMessageType('ListSourcesResponse', (_message.Message,), {

  'SourcesEntry' : _reflection.GeneratedProtocolMessageType('SourcesEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTSOURCESRESPONSE_SOURCESENTRY,
    '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.ListSourcesResponse.SourcesEntry)
    })
  ,
  'DESCRIPTOR' : _LISTSOURCESRESPONSE,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.ListSourcesResponse)
  })
_sym_db.RegisterMessage(ListSourcesResponse)
_sym_db.RegisterMessage(ListSourcesResponse.SourcesEntry)

ListTimelineTagsRequest = _reflection.GeneratedProtocolMessageType('ListTimelineTagsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTIMELINETAGSREQUEST,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.ListTimelineTagsRequest)
  })
_sym_db.RegisterMessage(ListTimelineTagsRequest)

ListTimelineTagsResponse = _reflection.GeneratedProtocolMessageType('ListTimelineTagsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTIMELINETAGSRESPONSE,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.ListTimelineTagsResponse)
  })
_sym_db.RegisterMessage(ListTimelineTagsResponse)

AddBandRequest = _reflection.GeneratedProtocolMessageType('AddBandRequest', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _ADDBANDREQUEST_PROPERTIESENTRY,
    '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.AddBandRequest.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _ADDBANDREQUEST,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.AddBandRequest)
  })
_sym_db.RegisterMessage(AddBandRequest)
_sym_db.RegisterMessage(AddBandRequest.PropertiesEntry)

GetBandRequest = _reflection.GeneratedProtocolMessageType('GetBandRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBANDREQUEST,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.GetBandRequest)
  })
_sym_db.RegisterMessage(GetBandRequest)

UpdateBandRequest = _reflection.GeneratedProtocolMessageType('UpdateBandRequest', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEBANDREQUEST_PROPERTIESENTRY,
    '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.UpdateBandRequest.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEBANDREQUEST,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.UpdateBandRequest)
  })
_sym_db.RegisterMessage(UpdateBandRequest)
_sym_db.RegisterMessage(UpdateBandRequest.PropertiesEntry)

ListBandsRequest = _reflection.GeneratedProtocolMessageType('ListBandsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBANDSREQUEST,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.ListBandsRequest)
  })
_sym_db.RegisterMessage(ListBandsRequest)

DeleteBandRequest = _reflection.GeneratedProtocolMessageType('DeleteBandRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBANDREQUEST,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.DeleteBandRequest)
  })
_sym_db.RegisterMessage(DeleteBandRequest)

ListBandsResponse = _reflection.GeneratedProtocolMessageType('ListBandsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTBANDSRESPONSE,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.ListBandsResponse)
  })
_sym_db.RegisterMessage(ListBandsResponse)

AddViewRequest = _reflection.GeneratedProtocolMessageType('AddViewRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDVIEWREQUEST,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.AddViewRequest)
  })
_sym_db.RegisterMessage(AddViewRequest)

GetViewRequest = _reflection.GeneratedProtocolMessageType('GetViewRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIEWREQUEST,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.GetViewRequest)
  })
_sym_db.RegisterMessage(GetViewRequest)

ListViewsRequest = _reflection.GeneratedProtocolMessageType('ListViewsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIEWSREQUEST,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.ListViewsRequest)
  })
_sym_db.RegisterMessage(ListViewsRequest)

UpdateViewRequest = _reflection.GeneratedProtocolMessageType('UpdateViewRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIEWREQUEST,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.UpdateViewRequest)
  })
_sym_db.RegisterMessage(UpdateViewRequest)

DeleteViewRequest = _reflection.GeneratedProtocolMessageType('DeleteViewRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIEWREQUEST,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.DeleteViewRequest)
  })
_sym_db.RegisterMessage(DeleteViewRequest)

ListViewsResponse = _reflection.GeneratedProtocolMessageType('ListViewsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIEWSRESPONSE,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.ListViewsResponse)
  })
_sym_db.RegisterMessage(ListViewsResponse)

ItemFilter = _reflection.GeneratedProtocolMessageType('ItemFilter', (_message.Message,), {

  'FilterCriterion' : _reflection.GeneratedProtocolMessageType('FilterCriterion', (_message.Message,), {
    'DESCRIPTOR' : _ITEMFILTER_FILTERCRITERION,
    '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.ItemFilter.FilterCriterion)
    })
  ,
  'DESCRIPTOR' : _ITEMFILTER,
  '__module__' : 'yamcs.protobuf.timeline.timeline_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.timeline.ItemFilter)
  })
_sym_db.RegisterMessage(ItemFilter)
_sym_db.RegisterMessage(ItemFilter.FilterCriterion)


DESCRIPTOR._options = None
_TIMELINEITEM_PROPERTIESENTRY._options = None
_TIMELINEBAND_PROPERTIESENTRY._options = None
_TIMELINEBAND.fields_by_name['tags']._options = None
_CREATEITEMREQUEST_PROPERTIESENTRY._options = None
_UPDATEITEMREQUEST_PROPERTIESENTRY._options = None
_LISTSOURCESRESPONSE_SOURCESENTRY._options = None
_ADDBANDREQUEST_PROPERTIESENTRY._options = None
_ADDBANDREQUEST.fields_by_name['tags']._options = None
_UPDATEBANDREQUEST_PROPERTIESENTRY._options = None

_TIMELINEAPI = _descriptor.ServiceDescriptor(
  name='TimelineApi',
  full_name='yamcs.protobuf.timeline.TimelineApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=5665,
  serialized_end=8507,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateItem',
    full_name='yamcs.protobuf.timeline.TimelineApi.CreateItem',
    index=0,
    containing_service=None,
    input_type=_CREATEITEMREQUEST,
    output_type=_TIMELINEITEM,
    serialized_options=b'\212\222\003#\032\036/api/timeline/{instance}/items:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='GetItem',
    full_name='yamcs.protobuf.timeline.TimelineApi.GetItem',
    index=1,
    containing_service=None,
    input_type=_GETITEMREQUEST,
    output_type=_TIMELINEITEM,
    serialized_options=b'\212\222\003%\n#/api/timeline/{instance}/items/{id}',
  ),
  _descriptor.MethodDescriptor(
    name='UpdateItem',
    full_name='yamcs.protobuf.timeline.TimelineApi.UpdateItem',
    index=2,
    containing_service=None,
    input_type=_UPDATEITEMREQUEST,
    output_type=_TIMELINEITEM,
    serialized_options=b'\212\222\003(\022#/api/timeline/{instance}/items/{id}:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='ListItems',
    full_name='yamcs.protobuf.timeline.TimelineApi.ListItems',
    index=3,
    containing_service=None,
    input_type=_LISTITEMSREQUEST,
    output_type=_LISTITEMSRESPONSE,
    serialized_options=b'\212\222\003 \n\036/api/timeline/{instance}/items',
  ),
  _descriptor.MethodDescriptor(
    name='DeleteItem',
    full_name='yamcs.protobuf.timeline.TimelineApi.DeleteItem',
    index=4,
    containing_service=None,
    input_type=_DELETEITEMREQUEST,
    output_type=_TIMELINEITEM,
    serialized_options=b'\212\222\003%\"#/api/timeline/{instance}/items/{id}',
  ),
  _descriptor.MethodDescriptor(
    name='GetItemLog',
    full_name='yamcs.protobuf.timeline.TimelineApi.GetItemLog',
    index=5,
    containing_service=None,
    input_type=_GETITEMLOGREQUEST,
    output_type=_TIMELINEITEMLOG,
    serialized_options=b'\212\222\003)\n\'/api/timeline/{instance}/items/{id}/log',
  ),
  _descriptor.MethodDescriptor(
    name='AddItemLog',
    full_name='yamcs.protobuf.timeline.TimelineApi.AddItemLog',
    index=6,
    containing_service=None,
    input_type=_ADDITEMLOGREQUEST,
    output_type=_LOGENTRY,
    serialized_options=b'\212\222\003)\032\'/api/timeline/{instance}/items/{id}/log',
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTimelineGroup',
    full_name='yamcs.protobuf.timeline.TimelineApi.DeleteTimelineGroup',
    index=7,
    containing_service=None,
    input_type=_DELETETIMELINEGROUPREQUEST,
    output_type=_TIMELINEITEM,
    serialized_options=b'\212\222\003&\"$/api/timeline/{instance}/groups/{id}',
  ),
  _descriptor.MethodDescriptor(
    name='ListSources',
    full_name='yamcs.protobuf.timeline.TimelineApi.ListSources',
    index=8,
    containing_service=None,
    input_type=_LISTSOURCESREQUEST,
    output_type=_LISTSOURCESRESPONSE,
    serialized_options=b'\212\222\003\"\n /api/timeline/{instance}/sources',
  ),
  _descriptor.MethodDescriptor(
    name='ListTags',
    full_name='yamcs.protobuf.timeline.TimelineApi.ListTags',
    index=9,
    containing_service=None,
    input_type=_LISTTIMELINETAGSREQUEST,
    output_type=_LISTTIMELINETAGSRESPONSE,
    serialized_options=b'\212\222\003\037\n\035/api/timeline/{instance}/tags',
  ),
  _descriptor.MethodDescriptor(
    name='AddBand',
    full_name='yamcs.protobuf.timeline.TimelineApi.AddBand',
    index=10,
    containing_service=None,
    input_type=_ADDBANDREQUEST,
    output_type=_TIMELINEBAND,
    serialized_options=b'\212\222\003#\032\036/api/timeline/{instance}/bands:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='GetBand',
    full_name='yamcs.protobuf.timeline.TimelineApi.GetBand',
    index=11,
    containing_service=None,
    input_type=_GETBANDREQUEST,
    output_type=_TIMELINEBAND,
    serialized_options=b'\212\222\003%\n#/api/timeline/{instance}/bands/{id}',
  ),
  _descriptor.MethodDescriptor(
    name='ListBands',
    full_name='yamcs.protobuf.timeline.TimelineApi.ListBands',
    index=12,
    containing_service=None,
    input_type=_LISTBANDSREQUEST,
    output_type=_LISTBANDSRESPONSE,
    serialized_options=b'\212\222\003 \n\036/api/timeline/{instance}/bands',
  ),
  _descriptor.MethodDescriptor(
    name='UpdateBand',
    full_name='yamcs.protobuf.timeline.TimelineApi.UpdateBand',
    index=13,
    containing_service=None,
    input_type=_UPDATEBANDREQUEST,
    output_type=_TIMELINEBAND,
    serialized_options=b'\212\222\003(\022#/api/timeline/{instance}/bands/{id}:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='DeleteBand',
    full_name='yamcs.protobuf.timeline.TimelineApi.DeleteBand',
    index=14,
    containing_service=None,
    input_type=_DELETEBANDREQUEST,
    output_type=_TIMELINEBAND,
    serialized_options=b'\212\222\003%\"#/api/timeline/{instance}/bands/{id}',
  ),
  _descriptor.MethodDescriptor(
    name='AddView',
    full_name='yamcs.protobuf.timeline.TimelineApi.AddView',
    index=15,
    containing_service=None,
    input_type=_ADDVIEWREQUEST,
    output_type=_TIMELINEVIEW,
    serialized_options=b'\212\222\003#\032\036/api/timeline/{instance}/views:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='GetView',
    full_name='yamcs.protobuf.timeline.TimelineApi.GetView',
    index=16,
    containing_service=None,
    input_type=_GETVIEWREQUEST,
    output_type=_TIMELINEVIEW,
    serialized_options=b'\212\222\003%\n#/api/timeline/{instance}/views/{id}',
  ),
  _descriptor.MethodDescriptor(
    name='ListViews',
    full_name='yamcs.protobuf.timeline.TimelineApi.ListViews',
    index=17,
    containing_service=None,
    input_type=_LISTVIEWSREQUEST,
    output_type=_LISTVIEWSRESPONSE,
    serialized_options=b'\212\222\003 \n\036/api/timeline/{instance}/views',
  ),
  _descriptor.MethodDescriptor(
    name='UpdateView',
    full_name='yamcs.protobuf.timeline.TimelineApi.UpdateView',
    index=18,
    containing_service=None,
    input_type=_UPDATEVIEWREQUEST,
    output_type=_TIMELINEVIEW,
    serialized_options=b'\212\222\003(\022#/api/timeline/{instance}/views/{id}:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='DeleteView',
    full_name='yamcs.protobuf.timeline.TimelineApi.DeleteView',
    index=19,
    containing_service=None,
    input_type=_DELETEVIEWREQUEST,
    output_type=_TIMELINEVIEW,
    serialized_options=b'\212\222\003%\"#/api/timeline/{instance}/views/{id}',
  ),
])
_sym_db.RegisterServiceDescriptor(_TIMELINEAPI)

DESCRIPTOR.services_by_name['TimelineApi'] = _TIMELINEAPI

# @@protoc_insertion_point(module_scope)
